==> sigi-1.1.0.crate: sigi-1.1.0/NOTES.md <==
# Similar projects

If sigi doesn't do quite what you want, check out these similar projects. Sigi
was created before I found these, but some inspiration may be gleaned from them
for improvement. Most in this list predate sigi by several years.

## Similar CLIs

- [devtodo](https://swapoff.org/devtodo.html) - A hierarchical command-line task manager
- [dstask](https://github.com/naggie/dstask) - Single binary terminal-based TODO manager with git-based sync + markdown notes per task
- [grit](https://github.com/climech/grit) - Multitree-based task manager
- [node-todo-cli](https://www.npmjs.com/package/node-todo-cli) - A command line program that manages todo tasks
- [py-todo-cli](https://github.com/Mantaseus/Todo-CLI) - A simple command line Todo program written in Python
- [taskell](https://taskell.app) - Command-line Kanban board/task management
- [taskwarrior](https://taskwarrior.org) - Taskwarrior is Free and Open Source Software that manages your TODO list from the command line
- [tax](https://github.com/netgusto/tax) - CLI task list manager
- [todo cli](https://gitlab.com/bigfiga99/todo-cli) - Todo CLI is a simple program that uses a sqlite3 database to keep track of your tasks
- [todo.txt](http://todotxt.org) - Future-proof task tracking in a file you control

### Similar CLI Definitions

- gophercises #7: [task](https://github.com/gophercises/task) - TODO CLI definition. (Defines a CLI)
- [pushpop](https://github.com/secretGeek/pushpop) - "Mental stack manager" definition. (Defines both a GUI and CLI)
  - See also implementations in [sh](https://paste.sr.ht/~erazemkokot/c6aeb2a7bc25049d08825b3cc7aea63b5cf72a08), [power shell](https://github.com/kberridge/psushpop/blob/master/psushpop.psm1)

## Similar non-CLI apps

- Too many to count. TODO apps are kind of the canonical JavaScript "first big project." They're also ubiquitous in mobile app stores.

## Similar Databases

- [piladb](https://github.com/fern4lvarez/piladb) - Stack-based database. (A working REST API and Database)

==> sigi-3.2.2.crate: sigi-3.2.2/NOTES.md <==
# Similar projects

If sigi doesn't do quite what you want, check out these similar projects. Sigi
was created before I found these, but some inspiration may be gleaned from them
for improvement. Most in this list predate sigi by several years.

## Similar CLIs

- [devtodo](https://swapoff.org/devtodo.html) - A hierarchical command-line task manager
- [dstask](https://github.com/naggie/dstask) - Single binary terminal-based TODO manager with git-based sync + markdown notes per task
- [geek-life](https://github.com/ajaxray/geek-life) - The CLI To-Do List / Task Manager for Geeks
- [grit](https://github.com/climech/grit) - Multitree-based task manager
- [node-todo-cli](https://www.npmjs.com/package/node-todo-cli) - A command line program that manages todo tasks
- [py-todo-cli](https://github.com/Mantaseus/Todo-CLI) - A simple command line Todo program written in Python
- [taskell](https://taskell.app) - Command-line Kanban board/task management
- [taskwarrior](https://taskwarrior.org) - Taskwarrior is Free and Open Source Software that manages your TODO list from the command line
- [tax](https://github.com/netgusto/tax) - CLI task list manager
- [todo cli](https://gitlab.com/bigfiga99/todo-cli) - Todo CLI is a simple program that uses a sqlite3 database to keep track of your tasks
- [todo.txt](http://todotxt.org) - Future-proof task tracking in a file you control
  - [todo.txt cli](https://github.com/todotxt/todo.txt-cli)
- [ultralist](https://ultralist.io) - Command-line task management for tech folks
- [yokadi](https://yokadi.github.io) - Yokadi is a command line oriented, sqlite powered, todo-list

### Similar CLI Definitions

- gophercises #7: [task](https://github.com/gophercises/task) - TODO CLI definition. (Defines a CLI)
- [pushpop](https://github.com/secretGeek/pushpop) - "Mental stack manager" definition. (Defines both a GUI and CLI)
  - See also implementations in [sh](https://paste.sr.ht/~erazemkokot/c6aeb2a7bc25049d08825b3cc7aea63b5cf72a08), [power shell](https://github.com/kberridge/psushpop/blob/master/psushpop.psm1)

## Similar non-CLI apps

- [GTG (Getting Things GNOME!)](https://wiki.gnome.org/Apps/GTG)
- [KTimeTracker](https://userbase.kde.org/KTimeTracker)
- But really... Just too many to list? TODO apps are kind of the canonical JavaScript "first big project." They're also ubiquitous in mobile app stores.

## Similar Databases

- [piladb](https://github.com/fern4lvarez/piladb) - Stack-based database. (A working REST API and Database)
